<?php
/**
 * Test for the LoginManager class
 * ===============================
 *
 * This example sets up an authorization system using the LoginManager
 * class. You don't have to use this to use the LiveUser class(es), but
 * this way you don't need to take care of the login-process, storing
 * the user object in a session and more...
 *
 * This example is intended to be used with the DB_Medium Perm driver.
 *
 * @version $Id: example_medium.php,v 1.9 2003/03/07 12:45:21 krausbn Exp $
 **/
error_reporting(E_ALL);

//ini_set("include_path", '.;/path/to/pear');

define('LIVEUSER_AREA_COFFEEMAKER',   1);
define('LIVEUSER_RIGHT_MAKE_COFFEE',  1);
define('LIVEUSER_RIGHT_DRINK_COFFEE', 2);

// Get LoginManager class definition
require_once 'Auth/LoginManager.php';

// The error handling stuff is not needed and used only for debugging
// while LiveUser is not yet mature
PEAR::setErrorHandling(PEAR_ERROR_CALLBACK, 'eHandler');

function eHandler($errObj)
{
    echo('<hr><font color=red>'.$errObj->getMessage().':<br>'.$errObj->getUserinfo().'</font><hr>');
}

// Create new LoginManager object, providing an XML file that contains
// configuration information
$LoMa = new LoginManager('demoConf.xml');

// this sets a callback function if the user hasn't logged in yet
$LoMa->setLoginFunction('testLogin');

/**
 * Example callback function on logging in
 */
function testLogin()
{
    header('Location: example.htm');
    exit();
} // end func testLogin

// Trigger the login process
$LoMa->init();

// Check if the user has logged in successfully
if (!$LoMa->isLoggedIn()) {
    // The user couldn't login, so let's check if the reason was that
    // he's not yet been declared "valid" by an administrator.
    if ($LoMa->isInactive()) {
        echo "Sorry kid, but one of our admins has yet to approve ";
        echo "your user status. Please be patient. Don't call us - ";
        echo "we'll call you.";
    } else {
        echo "Sorry, we can't let you in. Check if the spelling of ";
        echo "your handle and password is correct.";
    }
} else {
    // Okay, he's in. Now let's display some content dependent of
    // his access rights in our application. Let's pretend the current
    // AuthArea of our application is the Coffeemaker section and we won't to
    // know whether to user is allowd to make some coffee
    // (the area is not needed until we won't know whether our user is a area
    // admin).
    if ($level = $LoMa->checkRight(LIVEUSER_RIGHT_MAKE_COFFEE)) {
        echo "Congrats, you're in the Coffeemaker section and have ";
        echo 'the right to make coffee !';
    } else {
        echo "Your coffee tastes so bad, I won't allow you to make some";
    }

    // You can choose: either you set the area id as second parameter in
    // the checkRight function each time you call it or you set is ones for
    // all following calls.
    $LoMa->setCurrentArea(LIVEUSER_AREA_COFFEEMAKER);
    // You even can test on multi rights by putting them into an array.
    if ($level = $LoMa->checkRight(array(LIVEUSER_RIGHT_DRINK_COFFEE, LIVEUSER_RIGHT_MAKE_COFFEE))) {
        echo 'Yey ! You can even drink some coffee';
    } else {
        echo 'Well, sorry dude, you cannot drink in here';
    }
}

// Just some more debug output with no further relevance
echo '<hr><pre>';
print_r($LoMa);
echo '<hr>';
print_r($_SESSION);
echo '<hr>';
print_r($_POST);
echo '</pre>';

echo '<br>Handle:';
print_r($LoMa->getHandle());
echo '<br>User Type:';
print_r($LoMa->getProperty('userType'));
echo '<br>User Group Ids:';
print_r(implode(', ', $LoMa->getProperty('groupIds')));
?>